==> edimdownloader-1.0.0.tar.gz: edimdownloader-1.0.0/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
import os
import edimensionpkg

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the README file
with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()


def read_requirements(filename='requirements.txt'):
    """Reads the list of requirements from given file.
    :param filename: Filename to read the requirements from.
                     Uses ``'requirements.txt'`` by default.
    :return: Requirments as list of strings.
    """
    # allow for some leeway with the argument
    if not filename.startswith('requirements'):
        filename = 'requirements-' + filename
    if not os.path.splitext(filename)[1]:
        filename += '.txt'  # no extension, add default

    def valid_line(line):
        line = line.strip()
        return line and not any(line.startswith(p) for p in ('#', '-'))

    def extract_requirement(line):
        egg_eq = '#egg='
        if egg_eq in line:
            _, requirement = line.split(egg_eq, 1)
            return requirement
        return line

    with open(filename) as f:
        lines = f.readlines()
        return list(map(extract_requirement, filter(valid_line, lines)))

setup(
    name='edimdownloader',
    version=edimensionpkg.__version__,
    description='A downloader for Edimension',
    long_description=long_description,
    url='https://github.com/pypa/sampleproject',
    author=edimensionpkg.__author__,
    author_email='teckwu_ong@mymail.sutd.edu.sg',
    license=edimensionpkg.__license__,

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='sutd edimension',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=read_requirements(),
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'edimdownloader = edimensionpkg.__main__:main',
        ],
    },
)

==> edimdownloader-1.0.4.tar.gz: edimdownloader-1.0.4/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
import os
import edimensionpkg

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name='edimdownloader',
    version=edimensionpkg.__version__,
    description='A downloader for Edimension',
    long_description=long_description,
    url='https://github.com/pypa/sampleproject',
    author=edimensionpkg.__author__,
    author_email='teckwu_ong@mymail.sutd.edu.sg',
    license=edimensionpkg.__license__,

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='sutd edimension',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=["future",
                      "requests",
                      "beautifulsoup4",
                      "docopt",
                      "lxml"],
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    entry_points={
        'console_scripts': [
            'edimdownloader = edimensionpkg.__main__:main',
        ],
    },
)
